---
layout: default
title: monty.operator.md
nav_exclude: true
---

# monty.operator module

Useful additional functions for operators

## monty.operator.operator_from_str(op)

Return the operator associated to the given string op.

* **Raises**
  **KeyError** –